# Changelog

## [1.1.0](https://github.com/skiloop/simhash/compare/v1.0.7...v1.1.0) (2022-05-02)


### Features

* remove assert and set default dimension of fingerprints to 128 ([63731e5](https://github.com/skiloop/simhash/commit/63731e53a14c1254fc0e30c30aebb0062e58c7fd))


### Documentation

* update README.md ([4a13c01](https://github.com/skiloop/simhash/commit/4a13c01c53105bbea4e0724acd764eebc25b22f7))
